
CHANGES
=======


v0.4.1-beta
-----------

*Release date: 2016-04-12*

- Adding this CHANGES.rst file.
- Moving library sources to an ``src`` subdir and excluding the ``tests`` package from the installation.


v0.4.0-beta
-----------

*Release date: 2016-04-09*


- Major update to README.rst: describing library exceptions and utility functions.
- Simplified the low level json parser interface.
- The public interface has also changed a bit.


v0.3.4-beta
-----------

*Release date: 2015-05-07*

- Major update to README.rst: added a long description about the config objects and their usage.


v0.3.2-beta
-----------

*Release date: 2015-05-03*

- A lot of code/interface changes since the previous alpha release.
- Handling encodings based on byte order mark at the beginning of files.
- Better json config value mapper mechanism
- More flexible and configurable json parser.


v0.2.0-alpha
------------

*Release date: 2015-04-30*

First "working" version on pypi.
